@@ -4,16 +4,23 @@ use strict;
 use Mojo::ByteStream;
 
 use base 'Mojolicious::Plugin';
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
 sub register {
 	my ($self,$app,$conf) = @_;
 	
+	$conf->{'lang'} ||= 'en';
+	
 	$app->renderer->add_helper(
 		recaptcha_html => sub {
 			my $self = shift;
 			my ($error) = map { $_ ? "&error=$_" : "" } $self->stash('recaptcha_error');
 			return Mojo::ByteStream->new(<<HTML);
+  <script type="text/javascript">
+var RecaptchaOptions = {
+   lang : '$conf->{lang}',
+};
+</script>
   <script type="text/javascript"
      src="http://www.google.com/recaptcha/api/challenge?k=$conf->{public_key}$error">
   </script>
@@ -31,12 +38,11 @@ HTML
 	);
 	$app->renderer->add_helper(
 		recaptcha => sub {
-			my ($self,$challenge, $response) = @_;
-			$response ||= 'manual_challenge';
-			my $result;
-			$self->client->post_form(
+			my ($self,$cb) = @_;
+			
+			my @post_data = (
 				'http://www.google.com/recaptcha/api/verify', 
-				{
+				{ 
 					privatekey => $conf->{'private_key'},
 					remoteip   => 
 						$self->req->headers->header('X-Real-IP')
@@ -44,18 +50,29 @@ HTML
 						$self->tx->{remote_address},
 					challenge  => $self->req->param('recaptcha_challenge_field'),
 					response   => $self->req->param('recaptcha_response_field')
-				},
-				sub {
-					my $content = $_[1]->res->to_string;
-					$result = $content =~ /true/;
-					
-					$self->stash(recaptcha_error => $content =~ m{false\s*(.*)$}si)
-						unless $result
-					;
 				}
-			)->start;
+			);
+			my $callback = sub {
+				my $content = $_[1]->res->to_string;
+				my $result = $content =~ /true/;
+				
+				$self->stash(recaptcha_error => $content =~ m{false\s*(.*)$}si)
+					unless $result
+				;
+				$cb->($result) if $cb;
+				return $result;
+			};
 			
-			$result;
+			if ($cb) {
+				$self->ua->post_form(
+					@post_data,
+					$callback,
+				);
+			} else {
+				my $tx = $self->ua->post_form(@post_data);
+				
+				return $callback->('',$tx);
+			}
 		}
 	);
 }
@@ -68,20 +85,22 @@ Mojolicious::Plugin::Recaptcha - ReCaptcha plugin for Mojolicious framework
 
 =head1 VERSION
 
-0.2
+0.3
 
 =head1 SYNOPSIS
 
    # Mojolicious::Lite
    plugin recaptcha => { 
       public_key  => '...', 
-      private_key => '...'
+      private_key => '...',
+      lang        => 'ru' 
    };
    
    # Mojolicious
    $self->plugin(recaptcha => { 
       public_key  => '...', 
-      private_key => '...'
+      private_key => '...',
+      lang        => 'ru'
    });
    
    # template 
@@ -90,11 +109,46 @@ Mojolicious::Plugin::Recaptcha - ReCaptcha plugin for Mojolicious framework
       <input type="submit" value="submit" name="submit" />
    </form>
    
-   # checking
-   if ($self->recaptcha) {
+   # checking blocking way
+   $self->recaptcha;
+   if ($self->stash('recaptcha_error')) {
       # all ok
    }
    
+   # checking non-blocking way
+   $self->render_later;
+   $self->recaptcha(sub {
+      my $ok = shift;
+      if ($ok) {
+       
+      } else {
+         warn $self->stash('recaptcha_error');
+      }
+      # here you need call render
+      $self->render;
+   })
+
+=head1 Internationalisation support
+
+=over 4
+
+=item * English by default (en)
+
+=item * Dutch (nl)
+
+=item * French (fr)
+
+=item * German (de)
+
+=item * Portuguese (pt)
+
+=item * Russian (ru)
+
+=item * Spanish (es)
+
+=item * Turkish (tr)
+
+=back
 
 =head1 SUPPORT
 
@@ -110,8 +164,18 @@ L<http://github.com/konstantinov/Mojolicious-Plugin-Recaptcha>
 
 L<Mojolicious>, L<Mojolicious::Plugin>, L<Mojolicious::Lite>
 
+=head1 THANKS
+
+Special thanks for help in development
+
+=over 2
+
+Alexander Voronov
+
+=back
+
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Dmitry Konstantinov. All right reserved.
+Copyright 2010-2011 Dmitry Konstantinov. All right reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
